﻿using System;
using System.Collections.Generic;
using System.Web;
using Telerik.Web.UI;

/// <summary>
/// Summary description for AppointmentInfo
/// </summary>
public class AppointmentInfo
{
    private readonly string _id;
    private string _subject;
    private string _appointmentColor;
    private DateTime _start;
    private DateTime _end;
    private string _recurrenceRule;
    private string _recurrenceParentId;
    private string _reminder;
    private int? _userID;

    public string ID
    {
        get { return _id; }
    }

    public string Subject
    {
        get { return _subject; }
        set { _subject = value; }
    }
    public string AppointmentColor
    {
        get { return _appointmentColor; }
        set { _appointmentColor = value; }
    }

    public DateTime Start
    {
        get { return _start; }
        set { _start = value; }
    }

    public DateTime End
    {
        get { return _end; }
        set { _end = value; }
    }

    public string RecurrenceRule
    {
        get { return _recurrenceRule; }
        set { _recurrenceRule = value; }
    }

    public string RecurrenceParentID
    {
        get { return _recurrenceParentId; }
        set { _recurrenceParentId = value; }
    }

    public int? UserID
    {
        get { return _userID; }
        set { _userID = value; }
    }

    public string Reminder
    {
        get { return _reminder; }
        set { _reminder = value; }
    }

    private AppointmentInfo()
    {
        _id = Guid.NewGuid().ToString();
    }

    public AppointmentInfo(string subject, string appointmentColor, DateTime start, DateTime end,
        string recurrenceRule, string recurrenceParentID, string reminder, int? userID)
        : this()
    {
        _subject = subject;
        _appointmentColor = appointmentColor;
        _start = start;
        _end = end;
        _recurrenceRule = recurrenceRule;
        _recurrenceParentId = recurrenceParentID;
        _reminder = reminder;
        _userID = userID;
    }
    public AppointmentInfo(string subject, DateTime start, DateTime end)
        : this()
    {
        this.Subject = subject;
        this.Start = start;
        this.End = end;
    }

    public AppointmentInfo(Appointment source)
        : this()
    {
        CopyInfo(source);
    }

    public void CopyInfo(Appointment source)
    {
        Subject = source.Subject;
        AppointmentColor = source.Attributes["AppointmentColor"];
        Start = source.Start;
        End = source.End;
        RecurrenceRule = source.RecurrenceRule;
        if (source.RecurrenceParentID != null)
        {
            RecurrenceParentID = source.RecurrenceParentID.ToString();
        }

        if (!String.IsNullOrEmpty(Reminder))
        {
            Reminder = source.Reminders[0].ToString();
        }

        Resource user = source.Resources.GetResourceByType("User");
        if (user != null)
        {
            UserID = (int?)user.Key;
        }
        else
        {
            UserID = null;
        }
    }
}

